@@ -1,5 +1,8 @@
 // SPDX-License-Identifier: MIT
 
+#![cfg_attr(not(feature = "iter-mut"), forbid(unsafe_code))]
+#![cfg_attr(feature = "iter-mut", deny(unsafe_code))]
+
 use generational_arena::{Arena, Index};
 
 #[derive(Debug)]
@@ -17,7 +20,7 @@ struct Item<T> {
 ///
 /// # Examples
 /// ```
-/// # use generational_indexlist::{GenerationalTokenList, ItemToken};
+/// # use generational_token_list::{GenerationalTokenList, ItemToken};
 /// let mut list = GenerationalTokenList::<&str>::new();
 /// let item1: ItemToken = list.push_back("OK then buddy");
 /// assert_eq!(list.get(item1), Some(&"OK then buddy"));
@@ -26,7 +29,7 @@ struct Item<T> {
 /// Even if you remove other items and/or insert new items, tokens remain valid.
 ///
 /// ```
-/// # use generational_indexlist::{GenerationalTokenList, ItemToken};
+/// # use generational_token_list::{GenerationalTokenList, ItemToken};
 /// let mut list = GenerationalTokenList::new();
 /// let item1 = list.push_back(1);
 /// let item2 = list.push_back(2);
@@ -41,7 +44,7 @@ struct Item<T> {
 /// Trying to `get` an item via an invalid token will return `None`.
 ///
 /// ```
-/// # use generational_indexlist::{GenerationalTokenList, ItemToken};
+/// # use generational_token_list::{GenerationalTokenList, ItemToken};
 /// let mut list = GenerationalTokenList::new();
 /// let item1 = list.push_back(1);
 /// list.push_back(2);
@@ -52,7 +55,7 @@ struct Item<T> {
 /// Even if you re-insert the same data into the same place, the returned old token is still invalid.
 ///
 /// ```
-/// # use generational_indexlist::{GenerationalTokenList, ItemToken};
+/// # use generational_token_list::{GenerationalTokenList, ItemToken};
 /// let mut list = GenerationalTokenList::new();
 /// let item1 = list.push_back(1);
 /// list.push_back(2);
@@ -101,7 +104,7 @@ impl<T> GenerationalTokenList<T> {
     ///
     /// # Examples
     /// ```
-    /// # use generational_indexlist::GenerationalTokenList;
+    /// # use generational_token_list::GenerationalTokenList;
     /// let mut list = GenerationalTokenList::new();
     /// list.push_back(String::from("Hi, friend!"));
     /// ```
@@ -126,7 +129,7 @@ impl<T> GenerationalTokenList<T> {
     ///
     /// # Examples
     /// ```
-    /// # use generational_indexlist::GenerationalTokenList;
+    /// # use generational_token_list::GenerationalTokenList;
     /// let mut list = GenerationalTokenList::new();
     /// list.push_back("slice");
     /// list.push_back("and");
@@ -141,7 +144,7 @@ impl<T> GenerationalTokenList<T> {
     ///
     /// # Examples
     /// ```
-    /// # use generational_indexlist::GenerationalTokenList;
+    /// # use generational_token_list::GenerationalTokenList;
     /// let mut list = GenerationalTokenList::new();
     /// list.push_back("sugar");
     /// list.push_back("and");
@@ -157,7 +160,7 @@ impl<T> GenerationalTokenList<T> {
     ///
     /// # Examples
     /// ```
-    /// # use generational_indexlist::GenerationalTokenList;
+    /// # use generational_token_list::GenerationalTokenList;
     /// let mut list = GenerationalTokenList::new();
     /// list.push_back("slice");
     /// list.push_back("and");
@@ -172,7 +175,7 @@ impl<T> GenerationalTokenList<T> {
     ///
     /// # Examples
     /// ```
-    /// # use generational_indexlist::GenerationalTokenList;
+    /// # use generational_token_list::GenerationalTokenList;
     /// let mut list = GenerationalTokenList::new();
     /// list.push_back("sugar");
     /// list.push_back("and");
@@ -188,7 +191,7 @@ impl<T> GenerationalTokenList<T> {
     ///
     /// # Examples
     /// ```
-    /// # use generational_indexlist::GenerationalTokenList;
+    /// # use generational_token_list::GenerationalTokenList;
     /// let mut list = GenerationalTokenList::new();
     /// assert_eq!(list.head_token(), None);
     /// let head = list.push_back(1);
@@ -204,7 +207,7 @@ impl<T> GenerationalTokenList<T> {
     ///
     /// # Examples
     /// ```
-    /// # use generational_indexlist::GenerationalTokenList;
+    /// # use generational_token_list::GenerationalTokenList;
     /// let mut list = GenerationalTokenList::new();
     /// assert_eq!(list.tail_token(), None);
     /// list.push_back(1);
@@ -220,7 +223,7 @@ impl<T> GenerationalTokenList<T> {
     ///
     /// # Examples
     /// ```
-    /// # use generational_indexlist::GenerationalTokenList;
+    /// # use generational_token_list::GenerationalTokenList;
     /// let mut list = GenerationalTokenList::new();
     /// list.push_back(String::from("moo"));
     /// let moo_2 = list.push_back(String::from("moo"));
@@ -239,7 +242,7 @@ impl<T> GenerationalTokenList<T> {
     ///
     /// # Examples
     /// ```
-    /// # use generational_indexlist::GenerationalTokenList;
+    /// # use generational_token_list::GenerationalTokenList;
     /// let mut list = GenerationalTokenList::new();
     /// let one = list.push_back(1);
     /// let two = list.push_back(2);
@@ -290,7 +293,7 @@ impl<T> GenerationalTokenList<T> {
     ///
     /// # Examples
     /// ```
-    /// # use generational_indexlist::GenerationalTokenList;
+    /// # use generational_token_list::GenerationalTokenList;
     /// let mut list = GenerationalTokenList::new();
     /// list.push_back(1);
     /// list.push_back(2);
@@ -308,7 +311,7 @@ impl<T> GenerationalTokenList<T> {
     ///
     /// # Examples
     /// ```
-    /// # use generational_indexlist::GenerationalTokenList;
+    /// # use generational_token_list::GenerationalTokenList;
     /// let mut list = GenerationalTokenList::new();
     /// list.push_back(1);
     /// list.push_back(2);
@@ -325,7 +328,7 @@ impl<T> GenerationalTokenList<T> {
     ///
     /// # Examples
     /// ```
-    /// # use generational_indexlist::GenerationalTokenList;
+    /// # use generational_token_list::GenerationalTokenList;
     /// let mut list = GenerationalTokenList::new();
     /// assert_eq!(list.len(), 0);
     /// list.push_back(1);
@@ -341,7 +344,7 @@ impl<T> GenerationalTokenList<T> {
     ///
     /// # Examples
     /// ```
-    /// # use generational_indexlist::GenerationalTokenList;
+    /// # use generational_token_list::GenerationalTokenList;
     /// let mut list = GenerationalTokenList::<String>::with_capacity(10);
     /// assert_eq!(list.capacity(), 10);
     /// ```
@@ -353,7 +356,7 @@ impl<T> GenerationalTokenList<T> {
     ///
     /// # Examples
     /// ```
-    /// # use generational_indexlist::GenerationalTokenList;
+    /// # use generational_token_list::GenerationalTokenList;
     /// let mut list = GenerationalTokenList::new();
     /// let item1 = list.push_back(vec![0, 1, 2]);
     /// let item2 = list.push_back(vec![3, 4, 5]);
@@ -368,7 +371,7 @@ impl<T> GenerationalTokenList<T> {
     ///
     /// # Examples
     /// ```
-    /// # use generational_indexlist::GenerationalTokenList;
+    /// # use generational_token_list::GenerationalTokenList;
     /// let mut list = GenerationalTokenList::new();
     /// let item1 = list.push_back(vec![0, 1, 2]);
     /// let item2 = list.push_back(vec![3, 4, 5]);
@@ -389,7 +392,7 @@ impl<T> GenerationalTokenList<T> {
     ///
     /// # Examples
     /// ```
-    /// # use generational_indexlist::GenerationalTokenList;
+    /// # use generational_token_list::GenerationalTokenList;
     /// let mut list = GenerationalTokenList::new();
     /// let item1 = list.push_back(vec![0, 1, 2]);
     /// let item2 = list.push_back(vec![3, 4, 5]);
@@ -406,7 +409,7 @@ impl<T> GenerationalTokenList<T> {
     /// This will panic:
     ///
     /// ```should_panic
-    /// # use generational_indexlist::GenerationalTokenList;
+    /// # use generational_token_list::GenerationalTokenList;
     /// let mut list = GenerationalTokenList::new();
     /// let item1 = list.push_back(vec![0, 1, 2]);
     /// list.push_back(vec![3, 4, 5]);
@@ -417,7 +420,7 @@ impl<T> GenerationalTokenList<T> {
     /// Like `get_mut`, None will be returned if the token is invalid.
     ///
     /// ```
-    /// # use generational_indexlist::GenerationalTokenList;
+    /// # use generational_token_list::GenerationalTokenList;
     /// let mut list = GenerationalTokenList::new();
     /// let item1 = list.push_back(vec![0, 1, 2]);
     /// let item2 = list.push_back(vec![3, 4, 5]);
@@ -440,7 +443,7 @@ impl<T> GenerationalTokenList<T> {
     ///
     /// # Examples
     /// ```
-    /// # use generational_indexlist::GenerationalTokenList;
+    /// # use generational_token_list::GenerationalTokenList;
     /// let empty_list = GenerationalTokenList::<String>::new();
     /// assert!(empty_list.is_empty());
     /// ```
@@ -472,7 +475,7 @@ impl<T> GenerationalTokenList<T> {
     ///
     /// # Examples
     /// ```
-    /// # use generational_indexlist::{GenerationalTokenList, ItemToken};
+    /// # use generational_token_list::{GenerationalTokenList, ItemToken};
     /// struct Meta {
     ///     data: u8,
     ///     my_token: ItemToken,
@@ -509,7 +512,7 @@ impl<T> GenerationalTokenList<T> {
     ///
     /// # Examples
     /// ```
-    /// # use generational_indexlist::GenerationalTokenList;
+    /// # use generational_token_list::GenerationalTokenList;
     /// let mut list = GenerationalTokenList::new();
     /// let item1 = list.push_back("ITEM1");
     /// assert_eq!(list.get(item1), Some(&"ITEM1"));
@@ -525,7 +528,7 @@ impl<T> GenerationalTokenList<T> {
     ///
     /// # Examples
     /// ```
-    /// # use generational_indexlist::{GenerationalTokenList, ItemToken};
+    /// # use generational_token_list::{GenerationalTokenList, ItemToken};
     /// struct Meta {
     ///     data: u8,
     ///     my_token: ItemToken,
@@ -561,7 +564,7 @@ impl<T> GenerationalTokenList<T> {
     ///
     /// # Examples
     /// ```
-    /// # use generational_indexlist::GenerationalTokenList;
+    /// # use generational_token_list::GenerationalTokenList;
     /// let mut list = GenerationalTokenList::new();
     /// list.push_back(":)");
     /// list.push_back(":/");
@@ -582,7 +585,7 @@ impl<T> GenerationalTokenList<T> {
     ///
     /// # Examples
     /// ```
-    /// # use generational_indexlist::{GenerationalTokenList, ItemToken};
+    /// # use generational_token_list::{GenerationalTokenList, ItemToken};
     /// struct Meta {
     ///     data: u8,
     ///     my_token: ItemToken,
@@ -634,7 +637,7 @@ impl<T> GenerationalTokenList<T> {
     ///
     /// # Examples
     /// ```
-    /// # use generational_indexlist::GenerationalTokenList;
+    /// # use generational_token_list::GenerationalTokenList;
     /// let mut list = GenerationalTokenList::<i32>::new();
     /// let item1 = list.push_back(10);
     /// list.push_back(20);
@@ -655,7 +658,7 @@ impl<T> GenerationalTokenList<T> {
     ///
     /// # Examples
     /// ```
-    /// # use generational_indexlist::{GenerationalTokenList, ItemToken};
+    /// # use generational_token_list::{GenerationalTokenList, ItemToken};
     /// struct Meta {
     ///     data: u8,
     ///     my_token: ItemToken,
@@ -707,7 +710,7 @@ impl<T> GenerationalTokenList<T> {
     ///
     /// # Examples
     /// ```
-    /// # use generational_indexlist::GenerationalTokenList;
+    /// # use generational_token_list::GenerationalTokenList;
     /// let mut list = GenerationalTokenList::<i32>::new();
     /// list.push_back(20);
     /// list.push_back(100);
@@ -723,7 +726,7 @@ impl<T> GenerationalTokenList<T> {
     ///
     /// # Examples
     /// ```
-    /// # use generational_indexlist::GenerationalTokenList;
+    /// # use generational_token_list::GenerationalTokenList;
     /// let mut list = GenerationalTokenList::<i32>::new();
     /// list.push_back(5);
     /// list.push_back(6);
@@ -743,7 +746,7 @@ impl<T> GenerationalTokenList<T> {
     ///
     /// # Examples
     /// ```
-    /// # use generational_indexlist::GenerationalTokenList;
+    /// # use generational_token_list::GenerationalTokenList;
     /// let mut list = GenerationalTokenList::<i32>::new();
     /// list.push_back(5);
     /// list.push_back(6);
@@ -755,6 +758,7 @@ impl<T> GenerationalTokenList<T> {
     ///
     /// assert_eq!(list.into_iter().collect::<Vec<_>>(), vec![15, 16, 17]);
     /// ```
+    #[cfg(feature = "iter-mut")]
     pub fn iter_mut(&mut self) -> IterMut<T> {
         let head = self.head;
         IterMut {
@@ -772,7 +776,7 @@ impl<T> GenerationalTokenList<T> {
     /// # Examples
     ///
     /// ```
-    /// # use generational_indexlist::GenerationalTokenList;
+    /// # use generational_token_list::GenerationalTokenList;
     /// let mut list = GenerationalTokenList::<i32>::new();
     /// let item1 = list.push_back(5);
     /// let item2 = list.push_back(6);
@@ -793,7 +797,7 @@ impl<T> GenerationalTokenList<T> {
     /// # Examples
     ///
     /// ```
-    /// # use generational_indexlist::GenerationalTokenList;
+    /// # use generational_token_list::GenerationalTokenList;
     /// let mut list = GenerationalTokenList::<i32>::new();
     /// list.push_back(5);
     /// let item2 = list.push_back(6);
@@ -806,6 +810,7 @@ impl<T> GenerationalTokenList<T> {
     }
 }
 
+#[cfg(feature = "iter-mut")]
 pub struct IterMut<'a, T>
 where
     T: 'a,
@@ -814,6 +819,7 @@ where
     next_item: Option<ItemToken>,
 }
 
+#[cfg(feature = "iter-mut")]
 impl<'a, T> Iterator for IterMut<'a, T>
 where
     T: 'a,
@@ -825,6 +831,8 @@ where
 
         self.list.arena.get_mut(next_item.index).map(|i| {
             self.next_item = i.next;
+
+            #[cfg_attr(feature = "iter-mut", allow(unsafe_code))]
             unsafe { &mut *(&mut i.data as *mut T) }
         })
     }
@@ -895,7 +903,7 @@ where
     /// # Examples
     ///
     /// ```
-    /// # use generational_indexlist::GenerationalTokenList;
+    /// # use generational_token_list::GenerationalTokenList;
     /// let mut list = GenerationalTokenList::<i32>::new();
     /// list.push_back(5);
     /// list.push_back(6);
@@ -917,7 +925,7 @@ where
     /// # Examples
     ///
     /// ```
-    /// # use generational_indexlist::GenerationalTokenList;
+    /// # use generational_token_list::GenerationalTokenList;
     /// let mut list = GenerationalTokenList::<i32>::new();
     /// list.push_back(5);
     /// list.push_back(6);
